{
    "$graph": [
        {
            "class": "CommandLineTool",
            "label": "FragGeneScan: find (fragmented) genes in short reads",
            "doc": "FragGeneScan is an application for finding (fragmented) genes in short\nreads. It can also be applied to predict prokaryotic genes in incomplete\nassemblies or complete genomes.\n\nFragGeneScan was first released through omics website (http://omics.informatics.indiana.edu/FragGeneScan/)\nin March 2010, where you can find its old releases. FragGeneScan migrated to SourceForge in October, 2013\n(https://sourceforge.net/projects/fraggenescan/).\n\nVersion 1.20 can be downloaded here:\nhttps://sourceforge.net/projects/fraggenescan/files/\n",
            "baseCommand": [],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "types": [
                        {
                            "type": "record",
                            "name": "#FragGeneScan-model.yaml/model",
                            "fields": [
                                {
                                    "name": "#FragGeneScan-model.yaml/model/main",
                                    "type": "File"
                                },
                                {
                                    "name": "#FragGeneScan-model.yaml/model/prob_forward",
                                    "type": "File",
                                    "label": "Forward probability model"
                                },
                                {
                                    "name": "#FragGeneScan-model.yaml/model/prob_backward",
                                    "type": "File",
                                    "label": "Backward probability model"
                                },
                                {
                                    "name": "#FragGeneScan-model.yaml/model/prob_noncoding",
                                    "type": "File",
                                    "label": "Noncoding probability model"
                                },
                                {
                                    "name": "#FragGeneScan-model.yaml/model/prob_start",
                                    "type": "File",
                                    "label": "Start probability model"
                                },
                                {
                                    "name": "#FragGeneScan-model.yaml/model/prob_stop",
                                    "type": "File",
                                    "label": "Stop probability model"
                                },
                                {
                                    "name": "#FragGeneScan-model.yaml/model/prob_start1",
                                    "type": "File",
                                    "label": "Start1 probability model"
                                },
                                {
                                    "name": "#FragGeneScan-model.yaml/model/prob_stop1",
                                    "type": "File",
                                    "label": "Stop1 probability model"
                                },
                                {
                                    "name": "#FragGeneScan-model.yaml/model/pwm_dist",
                                    "type": "File",
                                    "label": "pwm distribution"
                                }
                            ]
                        }
                    ],
                    "class": "SchemaDefRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "hints": [
                {
                    "packages": [
                        {
                            "specs": [
                                "https://identifiers.org/rrid/RRID:SCR_011929"
                            ],
                            "version": [
                                "1.20"
                            ],
                            "package": "fraggenescan"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "doc": "True if the sequence file has complete genomic sequences\nFalse if the sequence file has short sequence reads\n",
                    "type": "boolean",
                    "inputBinding": {
                        "valueFrom": "${ if (self) {\n     return [ \"-w\", \"1\" ];\n   } else {\n     return [ \"-w\", \"0\" ];\n   }\n }\n"
                    },
                    "id": "#FragGeneScan1_20.cwl/completeSeq"
                },
                {
                    "type": "#FragGeneScan-model.yaml/model",
                    "id": "#FragGeneScan1_20.cwl/model"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "inputBinding": {
                        "prefix": "-s"
                    },
                    "id": "#FragGeneScan1_20.cwl/sequence"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "-p"
                    },
                    "id": "#FragGeneScan1_20.cwl/threadNumber"
                }
            ],
            "arguments": [
                "mkdir",
                "train",
                ";",
                "ln",
                "-s",
                "$(inputs.model.main.path)",
                "train/model",
                ";",
                "ln",
                "-s",
                "$(inputs.model.prob_forward.path)",
                "train/gene",
                ";",
                "ln",
                "-s",
                "$(inputs.model.prob_backward.path)",
                "train/rgene",
                ";",
                "ln",
                "-s",
                "$(inputs.model.prob_noncoding.path)",
                "train/noncoding",
                ";",
                "ln",
                "-s",
                "$(inputs.model.prob_start.path)",
                "train/start",
                ";",
                "ln",
                "-s",
                "$(inputs.model.prob_stop.path)",
                "train/stop",
                ";",
                "ln",
                "-s",
                "$(inputs.model.prob_start1.path)",
                "train/start1",
                ";",
                "ln",
                "-s",
                "$(inputs.model.prob_stop1.path)",
                "train/stop1",
                ";",
                "ln",
                "-s",
                "$(inputs.model.pwm_dist.path)",
                "train/pwm",
                ";",
                "FragGeneScan",
                "-o",
                "$(runtime.outdir)/predicted_cds",
                "-t",
                "model"
            ],
            "id": "#FragGeneScan1_20.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute",
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "outputBinding": {
                        "glob": "predicted_cds.faa"
                    },
                    "id": "#FragGeneScan1_20.cwl/predictedCDS"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "InterProScan: protein sequence classifier",
            "doc": "Version 5.21-60 can be downloaded here:\nhttps://github.com/ebi-pf-team/interproscan/wiki/HowToDownload\n\nDocumentation on how to run InterProScan 5 can be found here:\nhttps://github.com/ebi-pf-team/interproscan/wiki/HowToRun\n",
            "requirements": [
                {
                    "class": "SchemaDefRequirement",
                    "types": [
                        {
                            "type": "enum",
                            "name": "#InterProScan-apps.yaml/apps",
                            "symbols": [
                                "#InterProScan-apps.yaml/apps/TIGRFAM",
                                "#InterProScan-apps.yaml/apps/SFLD",
                                "#InterProScan-apps.yaml/apps/SUPERFAMILY",
                                "#InterProScan-apps.yaml/apps/Gene3D",
                                "#InterProScan-apps.yaml/apps/Hamap",
                                "#InterProScan-apps.yaml/apps/Coils",
                                "#InterProScan-apps.yaml/apps/ProSiteProfiles",
                                "#InterProScan-apps.yaml/apps/SMART",
                                "#InterProScan-apps.yaml/apps/CDD",
                                "#InterProScan-apps.yaml/apps/PRINTS",
                                "#InterProScan-apps.yaml/apps/PIRSF",
                                "#InterProScan-apps.yaml/apps/ProSitePatterns",
                                "#InterProScan-apps.yaml/apps/Pfam",
                                "#InterProScan-apps.yaml/apps/ProDom",
                                "#InterProScan-apps.yaml/apps/MobiDBLite"
                            ]
                        },
                        {
                            "type": "enum",
                            "name": "#InterProScan-protein_formats.yaml/protein_formats",
                            "symbols": [
                                "#InterProScan-protein_formats.yaml/protein_formats/TSV",
                                "#InterProScan-protein_formats.yaml/protein_formats/XML",
                                "#InterProScan-protein_formats.yaml/protein_formats/GFF3"
                            ]
                        }
                    ]
                }
            ],
            "hints": [
                {
                    "packages": [
                        {
                            "specs": [
                                "https://identifiers.org/rrid/RRID:SCR_005829"
                            ],
                            "version": [
                                "5.21-60"
                            ],
                            "package": "interproscan"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "#InterProScan-apps.yaml/apps"
                        }
                    ],
                    "inputBinding": {
                        "itemSeparator": ",",
                        "prefix": "--applications"
                    },
                    "id": "#InterProScan5.21-60.cwl/applications"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--input"
                    },
                    "id": "#InterProScan5.21-60.cwl/proteinFile"
                }
            ],
            "baseCommand": "interproscan.sh",
            "arguments": [
                {
                    "valueFrom": "i5_annotations",
                    "prefix": "--outfile"
                },
                {
                    "valueFrom": "TSV",
                    "prefix": "--formats"
                },
                "--disable-precalc",
                "--goterms",
                "--pathways",
                {
                    "valueFrom": "$(runtime.tmpdir)",
                    "prefix": "--tempdir"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "i5_annotations"
                    },
                    "id": "#InterProScan5.21-60.cwl/i5Annotations"
                }
            ],
            "id": "#InterProScan5.21-60.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "Workflow",
            "inputs": [
                {
                    "type": "File",
                    "label": "output of infernal's cmsearch",
                    "id": "#SSU-from-tablehits.cwl/table_hits"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#SSU-from-tablehits.cwl/extract_coords/matched_seqs_with_coords",
                    "id": "#SSU-from-tablehits.cwl/SSU_coordinates"
                }
            ],
            "steps": [
                {
                    "run": "#extract-coords-from-cmsearch.cwl",
                    "in": [
                        {
                            "source": "#SSU-from-tablehits.cwl/grep/SSUs",
                            "id": "#SSU-from-tablehits.cwl/extract_coords/infernal_matches"
                        }
                    ],
                    "out": [
                        "#SSU-from-tablehits.cwl/extract_coords/matched_seqs_with_coords"
                    ],
                    "id": "#SSU-from-tablehits.cwl/extract_coords"
                },
                {
                    "run": "#pull-SSUs.cwl",
                    "in": [
                        {
                            "source": "#SSU-from-tablehits.cwl/table_hits",
                            "id": "#SSU-from-tablehits.cwl/grep/hits"
                        }
                    ],
                    "out": [
                        "#SSU-from-tablehits.cwl/grep/SSUs"
                    ],
                    "id": "#SSU-from-tablehits.cwl/grep"
                }
            ],
            "id": "#SSU-from-tablehits.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "types": [
                        {
                            "type": "enum",
                            "name": "#biom-convert-table.yaml/table_type",
                            "label": "The type of the table to produce",
                            "symbols": [
                                "#biom-convert-table.yaml/table_type/OTU table",
                                "#biom-convert-table.yaml/table_type/Pathway table",
                                "#biom-convert-table.yaml/table_type/Function table",
                                "#biom-convert-table.yaml/table_type/Ortholog table",
                                "#biom-convert-table.yaml/table_type/Gene table",
                                "#biom-convert-table.yaml/table_type/Metabolite table",
                                "#biom-convert-table.yaml/table_type/Taxon table",
                                "#biom-convert-table.yaml/table_type/Table"
                            ]
                        }
                    ],
                    "class": "SchemaDefRequirement"
                }
            ],
            "hints": [
                {
                    "packages": [
                        {
                            "specs": [
                                "https://doi.org/10.1186/2047-217X-1-7"
                            ],
                            "version": [
                                "2.1.6"
                            ],
                            "package": "biom-format"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3746",
                    "inputBinding": {
                        "prefix": "--input-fp"
                    },
                    "id": "#biom-convert.cwl/biom"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "label": "Output as HDF5-formatted table.",
                    "inputBinding": {
                        "prefix": "--to-hdf5"
                    },
                    "id": "#biom-convert.cwl/hdf5"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "The observation metadata to include from the input BIOM table file when\ncreating a tsv table file. By default no observation metadata will be\nincluded.\n",
                    "inputBinding": {
                        "prefix": "--header-key"
                    },
                    "id": "#biom-convert.cwl/header_key"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "label": "Output as JSON-formatted table.",
                    "inputBinding": {
                        "prefix": "--to-json"
                    },
                    "id": "#biom-convert.cwl/json"
                },
                {
                    "type": [
                        "null",
                        "#biom-convert-table.yaml/table_type"
                    ],
                    "inputBinding": {
                        "prefix": "--table-type"
                    },
                    "id": "#biom-convert.cwl/table_type"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "label": "Output as TSV-formatted (classic) table.",
                    "inputBinding": {
                        "prefix": "--to-tsv"
                    },
                    "id": "#biom-convert.cwl/tsv"
                }
            ],
            "baseCommand": [
                "biom",
                "convert"
            ],
            "arguments": [
                {
                    "valueFrom": "result",
                    "prefix": "--output-fp"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "result"
                    },
                    "id": "#biom-convert.cwl/result"
                }
            ],
            "id": "#biom-convert.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "remove lower scoring overlaps from cmsearch --tblout files.",
            "doc": "https://github.com/nawrockie/cmsearch_tblout_deoverlap/blob/master/00README.txt",
            "hints": [
                {
                    "class": "SoftwareRequirement",
                    "packages": [
                        {
                            "specs": [
                                "https://github.com/nawrockie/cmsearch_tblout_deoverlap"
                            ],
                            "package": "cmsearch_tblout_deoverlap"
                        }
                    ]
                }
            ],
            "requirements": [
                {
                    "envDef": [
                        {
                            "envValue": "C",
                            "envName": "LC_ALL"
                        }
                    ],
                    "class": "EnvVarRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "inputs": [
                {
                    "label": "clan information on the models provided",
                    "type": [
                        "null",
                        "File"
                    ],
                    "doc": "Not all models provided need to be a member of a clan",
                    "id": "#cmsearch-deoverlap.cwl/clan_information"
                },
                {
                    "type": "File",
                    "id": "#cmsearch-deoverlap.cwl/cmsearch_matches"
                }
            ],
            "baseCommand": [],
            "arguments": [
                "ln",
                "-s",
                "$(inputs.cmsearch_matches.path)",
                "$(inputs.cmsearch_matches.basename)",
                ";",
                "cmsearch-deoverlap.pl",
                "$(inputs.cmsearch_matches.basename)",
                "--clanin",
                "$(inputs.clan_information.path)"
            ],
            "outputs": [
                {
                    "label": "target hits table, format 2",
                    "doc": "http://eddylab.org/infernal/Userguide.pdf#page=60",
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.deoverlapped"
                    },
                    "id": "#cmsearch-deoverlap.cwl/deoverlapped_matches"
                }
            ],
            "id": "#cmsearch-deoverlap.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#concatenate.cwl/files"
                }
            ],
            "baseCommand": "cat",
            "stdout": "result",
            "outputs": [
                {
                    "type": "File",
                    "id": "#concatenate.cwl/result",
                    "outputBinding": {
                        "glob": "result"
                    }
                }
            ],
            "id": "#concatenate.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "drop short seqs",
            "hints": [
                {
                    "class": "SoftwareRequirement",
                    "packages": [
                        {
                            "specs": [
                                "https://identifiers.org/rrid/RRID:SCR_007173"
                            ],
                            "version": [
                                "1.65",
                                "1.66",
                                "1.69"
                            ],
                            "package": "biopython"
                        }
                    ]
                }
            ],
            "inputs": [
                {
                    "type": "int",
                    "label": "discard if number of bases is less than this amount",
                    "id": "#discard_short_seqs.cwl/minimum_length"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "id": "#discard_short_seqs.cwl/sequences"
                }
            ],
            "baseCommand": [
                "python"
            ],
            "arguments": [
                {
                    "valueFrom": "from Bio import SeqIO\ninput_seq_iterator = SeqIO.parse(\"$(inputs.sequences.path)\", \"fasta\")\nshort_seq_iterator = (record for record in input_seq_iterator if len(record.seq) >= $(inputs.minimum_length))\nSeqIO.write(short_seq_iterator, \"$(inputs.sequences.basename).filtered.fasta\", \"fasta\")\n",
                    "prefix": "-c"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.sequences.basename).filtered.fasta"
                    },
                    "format": "http://edamontology.org/format_1929",
                    "id": "#discard_short_seqs.cwl/filtered_sequences"
                }
            ],
            "id": "#discard_short_seqs.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "normalize to fasta",
            "doc": "normalizes input sequeces to FASTA with fixed number of sequence characters\nper line using esl-reformat from https://github.com/EddyRivasLab/easel\n",
            "requirements": [
                {
                    "types": [
                        {
                            "type": "record",
                            "name": "#esl-reformat-replace.yaml/replace",
                            "label": "sequence token replacement",
                            "fields": [
                                {
                                    "name": "#esl-reformat-replace.yaml/replace/find",
                                    "type": "string",
                                    "label": null,
                                    "doc": "Must be equal length with \"replace\". Each character from the input file\nwill be replaced by its counterpart (at the same position) from \"replace\"\n"
                                },
                                {
                                    "name": "#esl-reformat-replace.yaml/replace/replace",
                                    "type": "string",
                                    "label": null,
                                    "doc": "must be equal length with \"find\""
                                }
                            ]
                        }
                    ],
                    "class": "SchemaDefRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "#esl-reformat-replace.yaml/replace"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--replace",
                        "valueFrom": "$(self.find):$(self.replace)"
                    },
                    "id": "#esl-reformat.cwl/replace"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 3
                    },
                    "format": [
                        "http://edamontology.org/format_1930",
                        "http://edamontology.org/format_1929",
                        "http://edamontology.org/format_1927",
                        "http://edamontology.org/format_1936",
                        "http://edamontology.org/format_1961",
                        "http://edamontology.org/format_1963"
                    ],
                    "id": "#esl-reformat.cwl/sequences"
                }
            ],
            "baseCommand": [
                "esl-reformat"
            ],
            "arguments": [
                {
                    "valueFrom": "fasta",
                    "position": 2
                }
            ],
            "stdout": "reformatted_sequences",
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "id": "#esl-reformat.cwl/reformatted_sequences",
                    "outputBinding": {
                        "glob": "reformatted_sequences"
                    }
                }
            ],
            "id": "#esl-reformat.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "index a sequence file for use by esl-sfetch",
            "doc": "https://github.com/EddyRivasLab/easel",
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 10,
                        "valueFrom": "$(self.basename)"
                    },
                    "format": [
                        "http://edamontology.org/format_1929",
                        "http://edamontology.org/format_1927",
                        "http://edamontology.org/format_1936",
                        "http://edamontology.org/format_1961",
                        "http://edamontology.org/format_1963"
                    ],
                    "id": "#esl-sfetch-index.cwl/sequences"
                }
            ],
            "baseCommand": [],
            "arguments": [
                "cp",
                "$(inputs.sequences.path)",
                "$(runtime.outdir)",
                {
                    "valueFrom": ";",
                    "shellQuote": false
                },
                "esl-sfetch",
                "--index"
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": ".ssi",
                    "format": "$(inputs.sequences.format)",
                    "outputBinding": {
                        "glob": "$(inputs.sequences.basename)"
                    },
                    "id": "#esl-sfetch-index.cwl/sequences_with_index"
                }
            ],
            "id": "#esl-sfetch-index.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "extract by names from an indexed sequence file",
            "doc": "https://github.com/EddyRivasLab/easel",
            "inputs": [
                {
                    "label": "sequence file indexed by esl-sfetch-index",
                    "type": "File",
                    "secondaryFiles": ".ssi",
                    "inputBinding": {
                        "prefix": "-f",
                        "position": 1
                    },
                    "format": [
                        "http://edamontology.org/format_1929",
                        "http://edamontology.org/format_1927",
                        "http://edamontology.org/format_1936",
                        "http://edamontology.org/format_1961",
                        "http://edamontology.org/format_1963"
                    ],
                    "id": "#esl-sfetch-manyseqs.cwl/indexed_sequences"
                },
                {
                    "type": "File",
                    "label": "sequence names to retrieve, one per line",
                    "streamable": true,
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#esl-sfetch-manyseqs.cwl/names"
                },
                {
                    "doc": "GDF format: <newname> <from> <to> <source seqname>\nspace/tabdelimited\n",
                    "type": "boolean",
                    "inputBinding": {
                        "prefix": "-C"
                    },
                    "id": "#esl-sfetch-manyseqs.cwl/names_contain_subseq_coords"
                }
            ],
            "baseCommand": [
                "esl-sfetch"
            ],
            "stdout": "sequences",
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "id": "#esl-sfetch-manyseqs.cwl/sequences",
                    "outputBinding": {
                        "glob": "sequences"
                    }
                }
            ],
            "id": "#esl-sfetch-manyseqs.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "inputs": [
                {
                    "label": "output from infernal cmsearch",
                    "type": "File",
                    "streamable": true,
                    "id": "#extract-coords-from-cmsearch.cwl/infernal_matches"
                }
            ],
            "baseCommand": "awk",
            "stdout": "matched_seqs_with_coords",
            "arguments": [
                "{print $1\"-\"$3\"/\"$8\"-\"$9\" \"$8\" \"$9\" \"$1}",
                "$(inputs.infernal_matches.path)"
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#extract-coords-from-cmsearch.cwl/matched_seqs_with_coords",
                    "outputBinding": {
                        "glob": "matched_seqs_with_coords"
                    }
                }
            ],
            "doc": "The awk script takes the output of Infernal's cmsearch so-called fmt=1 mode\nand makes it suitable for use by esl-sfetch, a sequence selector\n\nReading the user's guide for Infernal, Version 1.1.2; July 2016\nhttp://eddylab.org/infernal/Userguide.pdf#page=60 we see that\nthe relevant fields in the cmsearch output are:\n(column number: explanation)\n1: The name of the target sequence or profile\n3: The name of the query sequence or profile\n8: The start of the alignment of this hit with respect to the\n    sequence, numbered 1..L for a sequence of L residues.\n9: The end of the alignment of this hit with respect to the sequence,\n    numbered 1..L for a sequence of L residues\n\nLikewise the format esl-sfetch wants is: <newname> <from> <to> <source seqname>\n\nPutting it all together we see that the newname (which esl-sfetch with\noutput using) is a concatenation of the original name, the sequence\nnumber, and the coordinates.\n",
            "id": "#extract-coords-from-cmsearch.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "split FASTA by number of records",
            "doc": "based upon code by Maxim Scheremetjew, EMBL-EBI",
            "hints": [
                {
                    "class": "SoftwareRequirement",
                    "packages": [
                        {
                            "specs": [
                                "https://identifiers.org/rrid/RRID:SCR_007173"
                            ],
                            "version": [
                                "1.65",
                                "1.66",
                                "1.69"
                            ],
                            "package": "biopython"
                        }
                    ]
                }
            ],
            "inputs": [
                {
                    "type": "int",
                    "id": "#fasta_chunker.cwl/chunk_size"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "id": "#fasta_chunker.cwl/seqs"
                }
            ],
            "baseCommand": "python",
            "arguments": [
                {
                    "prefix": "-c",
                    "valueFrom": "from Bio import SeqIO\ncurrentSequences = []\nfor record in SeqIO.parse(\"$(inputs.seqs.path)\", \"fasta\"):\n    currentSequences.append(record)\n    if len(currentSequences) == $(inputs.chunk_size):\n        fileName = currentSequences[0].id + \"_\" + currentSequences[-1].id\n        fileName = fileName.replace(\"/\", \"_\").replace(\" \", \"_\")\n        SeqIO.write(currentSequences, \"$(runtime.outdir)/\"+fileName, \"fasta\")\n        currentSequences = []\n\n# write any remaining sequences\nif len(currentSequences) > 0:\n    fileName = currentSequences[0].id + \"_\" + currentSequences[-1].id\n    fileName = fileName.replace(\"/\", \"_\").replace(\" \", \"_\")\n    SeqIO.write(currentSequences, \"$(runtime.outdir)/\"+fileName, \"fasta\")\n"
                }
            ],
            "outputs": [
                {
                    "format": "http://edamontology.org/format_1929",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "*"
                    },
                    "id": "#fasta_chunker.cwl/chunks"
                }
            ],
            "id": "#fasta_chunker.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "packages": [
                        {
                            "specs": [
                                "https://identifiers.org/rrid/RRID:SCR_005732"
                            ],
                            "version": [
                                "8d53bbce1ffe60d9aa3357c1001599f9a882317a"
                            ],
                            "package": "owltools"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--input-file"
                    },
                    "id": "#go_summary.cwl/InterProScan_results"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--config"
                    },
                    "id": "#go_summary.cwl/config"
                }
            ],
            "baseCommand": "go_summary_pipeline-1.0.py",
            "arguments": [
                {
                    "valueFrom": "go-summary",
                    "prefix": "--output-file"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "go-summary"
                    },
                    "id": "#go_summary.cwl/go_summary"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "go-summary_slim"
                    },
                    "id": "#go_summary.cwl/go_summary_slim"
                }
            ],
            "id": "#go_summary.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "search sequence(s) against a covariance model database",
            "doc": "http://eddylab.org/infernal/Userguide.pdf",
            "hints": [
                {
                    "class": "SoftwareRequirement",
                    "packages": [
                        {
                            "specs": [
                                "https://identifiers.org/rrid/RRID:SCR_011809"
                            ],
                            "version": [
                                "1.1.2"
                            ],
                            "package": "infernal"
                        }
                    ]
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#infernal-cmsearch.cwl/covariance_model_database"
                },
                {
                    "label": "use CM's GA gathering cutoffs as reporting thresholds",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": false,
                    "inputBinding": {
                        "prefix": "--cut_ga"
                    },
                    "id": "#infernal-cmsearch.cwl/cut_ga"
                },
                {
                    "label": "Omit the alignment section from the main output.",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--noali"
                    },
                    "doc": "This can greatly reduce the output volume.",
                    "id": "#infernal-cmsearch.cwl/omit_alignment_section"
                },
                {
                    "label": "Only use the filter profile HMM for searches, do not use the CM",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": false,
                    "inputBinding": {
                        "prefix": "--hmmonly"
                    },
                    "doc": "Only filter stages F1 through F3 will be executed, using strict P-value\nthresholds (0.02 for F1, 0.001 for F2 and 0.00001 for F3). Additionally\na bias composition filter is used after the F1 stage (with P=0.02\nsurvival threshold).  Any hit that survives all stages and has an HMM\nE-value or bit score above the reporting threshold will be output. \n",
                    "id": "#infernal-cmsearch.cwl/only_hmm"
                },
                {
                    "type": "File",
                    "streamable": true,
                    "inputBinding": {
                        "position": 1
                    },
                    "format": [
                        "http://edamontology.org/format_1929",
                        "http://edamontology.org/format_1927",
                        "http://edamontology.org/format_1936",
                        "http://edamontology.org/format_1961",
                        "http://edamontology.org/format_3281",
                        "http://edamontology.org/format_1982",
                        "http://edamontology.org/format_1997"
                    ],
                    "id": "#infernal-cmsearch.cwl/query_sequences"
                },
                {
                    "type": "int",
                    "label": "search space size in *Mb* to <x> for E-value calculations",
                    "inputBinding": {
                        "prefix": "-Z"
                    },
                    "id": "#infernal-cmsearch.cwl/search_space_size"
                }
            ],
            "baseCommand": "cmsearch",
            "arguments": [
                {
                    "valueFrom": "matches.tbl",
                    "prefix": "--tblout"
                },
                {
                    "valueFrom": "$(runtime.cores)",
                    "prefix": "--cpu"
                }
            ],
            "outputs": [
                {
                    "label": "target hits table, format 2",
                    "doc": "http://eddylab.org/infernal/Userguide.pdf#page=60",
                    "type": "File",
                    "outputBinding": {
                        "glob": "matches.tbl"
                    },
                    "id": "#infernal-cmsearch.cwl/matches"
                }
            ],
            "id": "#infernal-cmsearch.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "visualize using krona",
            "baseCommand": "ktImportText",
            "hints": [
                {
                    "packages": [
                        {
                            "specs": [
                                "https://identifiers.org/rrid/RRID:SCR_012785"
                            ],
                            "version": [
                                "2.3",
                                "2.7"
                            ],
                            "package": "krona"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "format": "#krona.cwl/text/tab-separated-values",
                    "label": "Tab-delimited text file",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#krona.cwl/otu_counts"
                }
            ],
            "arguments": [
                {
                    "valueFrom": "$(inputs.otu_counts.basename).html",
                    "prefix": "-o"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "format": "#krona.cwl/text/html",
                    "outputBinding": {
                        "glob": "$(inputs.otu_counts.basename).html"
                    },
                    "id": "#krona.cwl/otu_visualization"
                }
            ],
            "id": "#krona.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "MAPseq",
            "doc": "sequence read classification tools designed to assign taxonomy and OTU\nclassifications to ribosomal RNA sequences.\nhttp://meringlab.org/software/mapseq/\n",
            "hints": [
                {
                    "packages": [
                        {
                            "version": [
                                "1.0"
                            ],
                            "package": "mapseq"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "secondaryFiles": ".mscluster",
                    "inputBinding": {
                        "position": 2
                    },
                    "format": "http://edamontology.org/format_1929",
                    "id": "#mapseq.cwl/database"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "format": "http://edamontology.org/format_1929",
                    "id": "#mapseq.cwl/sequences"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#mapseq.cwl/taxonomy"
                }
            ],
            "baseCommand": "mapseq",
            "arguments": [
                {
                    "valueFrom": "4",
                    "prefix": "-nthreads"
                }
            ],
            "stdout": "classifications",
            "outputs": [
                {
                    "type": "File",
                    "format": "#mapseq.cwl/text/tab-separated-values",
                    "id": "#mapseq.cwl/classifications",
                    "outputBinding": {
                        "glob": "classifications"
                    }
                }
            ],
            "id": "#mapseq.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "inputs": [
                {
                    "type": "string",
                    "label": "label to add to the top of the outfile OTU table",
                    "inputBinding": {
                        "prefix": "--label"
                    },
                    "id": "#mapseq2biom.cwl/label"
                },
                {
                    "type": "File",
                    "label": "the OTU table produced for the taxonomies found in the reference databases that was used with MAPseq",
                    "inputBinding": {
                        "prefix": "--otuTable"
                    },
                    "id": "#mapseq2biom.cwl/otu_table"
                },
                {
                    "type": "File",
                    "label": "the output from the MAPseq that assigns a taxonomy to a sequence",
                    "inputBinding": {
                        "prefix": "--query"
                    },
                    "id": "#mapseq2biom.cwl/query"
                }
            ],
            "baseCommand": "mapseq2biom.pl",
            "arguments": [
                {
                    "valueFrom": "$(inputs.query.basename).tsv",
                    "prefix": "--outfile"
                },
                {
                    "valueFrom": "$(inputs.label).txt",
                    "prefix": "--krona"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "format": "#mapseq2biom.cwl/text/tab-separated-values",
                    "outputBinding": {
                        "glob": "$(inputs.label).txt"
                    },
                    "id": "#mapseq2biom.cwl/krona_otu_counts"
                },
                {
                    "type": "File",
                    "format": "#mapseq2biom.cwl/text/tab-separated-values",
                    "outputBinding": {
                        "glob": "$(inputs.query.basename).tsv"
                    },
                    "id": "#mapseq2biom.cwl/otu_counts"
                }
            ],
            "id": "#mapseq2biom.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "metaSPAdes: de novo metagenomics assembler",
            "doc": "https://arxiv.org/abs/1604.03071\nhttp://cab.spbu.ru/files/release3.10.1/manual.html#meta\n",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "ramMin": 102400,
                    "class": "ResourceRequirement"
                },
                {
                    "packages": [
                        {
                            "specs": [
                                "https://identifiers.org/rrid/RRID:SCR_000131"
                            ],
                            "version": [
                                "3.10.1"
                            ],
                            "package": "spades"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "-1"
                    },
                    "id": "#metaspades.cwl/forward_reads"
                },
                {
                    "label": "Set memory limit in Gb",
                    "doc": "SPAdes terminates if it reaches this limit. Actual amount of consumed\nRAM will be below this limit. Make sure the provided value is correct for\nthe given machine. SPAdes uses the limit value to automatically determine\nthe sizes of various buffers, etc.\n",
                    "type": "int",
                    "inputBinding": {
                        "prefix": "--memory"
                    },
                    "id": "#metaspades.cwl/memory_limit"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "-2"
                    },
                    "id": "#metaspades.cwl/reverse_reads"
                },
                {
                    "label": "Number of threads",
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 1,
                    "inputBinding": {
                        "prefix": "--threads"
                    },
                    "id": "#metaspades.cwl/threads"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "-s"
                    },
                    "id": "#metaspades.cwl/unpaired_reads"
                }
            ],
            "baseCommand": [
                "metaspades.py"
            ],
            "arguments": [
                {
                    "valueFrom": "$(runtime.outdir)",
                    "prefix": "-o"
                },
                {
                    "valueFrom": "$(runtime.tmpdir)",
                    "prefix": "--tmp-dir"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "assembly_graph.fastg"
                    },
                    "id": "#metaspades.cwl/assembly_graph"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "outputBinding": {
                        "glob": "contigs.fasta"
                    },
                    "id": "#metaspades.cwl/contigs"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "contigs.paths"
                    },
                    "id": "#metaspades.cwl/contigs_assembly_graph"
                },
                {
                    "label": "contigs before repeat resolution",
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "outputBinding": {
                        "glob": "before_rr.fasta"
                    },
                    "id": "#metaspades.cwl/contigs_before_rr"
                },
                {
                    "label": "internal configuration file",
                    "type": "File",
                    "outputBinding": {
                        "glob": "dataset.info"
                    },
                    "id": "#metaspades.cwl/internal_config"
                },
                {
                    "label": "internal YAML data set file",
                    "type": "File",
                    "outputBinding": {
                        "glob": "input_dataset.yaml"
                    },
                    "id": "#metaspades.cwl/internal_dataset"
                },
                {
                    "label": "SPAdes log",
                    "type": "File",
                    "format": "#metaspades.cwl/text/plain",
                    "outputBinding": {
                        "glob": "spades.log"
                    },
                    "id": "#metaspades.cwl/log"
                },
                {
                    "label": "information about SPAdes parameters in this run",
                    "type": "File",
                    "format": "#metaspades.cwl/text/plain",
                    "outputBinding": {
                        "glob": "params.txt"
                    },
                    "id": "#metaspades.cwl/params"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "outputBinding": {
                        "glob": "scaffolds.fasta"
                    },
                    "id": "#metaspades.cwl/scaffolds"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "scaffolds.paths"
                    },
                    "id": "#metaspades.cwl/scaffolds_assembly_graph"
                }
            ],
            "id": "#metaspades.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "inputs": [
                {
                    "type": "File",
                    "streamable": true,
                    "id": "#pull-SSUs.cwl/hits"
                }
            ],
            "baseCommand": [
                "grep",
                "SSU"
            ],
            "stdout": "SSUs",
            "arguments": [
                "$(inputs.hits.path)"
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#pull-SSUs.cwl/SSUs",
                    "outputBinding": {
                        "glob": "SSUs"
                    }
                }
            ],
            "id": "#pull-SSUs.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#cmsearch-multimodel.cwl/clan_info"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#cmsearch-multimodel.cwl/covariance_models"
                },
                {
                    "type": "File",
                    "id": "#cmsearch-multimodel.cwl/query_sequences"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#cmsearch-multimodel.cwl/remove_overlaps/deoverlapped_matches",
                    "id": "#cmsearch-multimodel.cwl/matches"
                }
            ],
            "steps": [
                {
                    "run": "#infernal-cmsearch.cwl",
                    "in": [
                        {
                            "source": "#cmsearch-multimodel.cwl/covariance_models",
                            "id": "#cmsearch-multimodel.cwl/cmsearch/covariance_model_database"
                        },
                        {
                            "default": true,
                            "id": "#cmsearch-multimodel.cwl/cmsearch/omit_alignment_section"
                        },
                        {
                            "default": true,
                            "id": "#cmsearch-multimodel.cwl/cmsearch/only_hmm"
                        },
                        {
                            "source": "#cmsearch-multimodel.cwl/query_sequences",
                            "id": "#cmsearch-multimodel.cwl/cmsearch/query_sequences"
                        },
                        {
                            "default": 1000,
                            "id": "#cmsearch-multimodel.cwl/cmsearch/search_space_size"
                        }
                    ],
                    "out": [
                        "#cmsearch-multimodel.cwl/cmsearch/matches"
                    ],
                    "scatter": "#cmsearch-multimodel.cwl/cmsearch/covariance_model_database",
                    "id": "#cmsearch-multimodel.cwl/cmsearch"
                },
                {
                    "run": "#concatenate.cwl",
                    "in": [
                        {
                            "source": "#cmsearch-multimodel.cwl/cmsearch/matches",
                            "id": "#cmsearch-multimodel.cwl/concatenate_matches/files"
                        }
                    ],
                    "out": [
                        "#cmsearch-multimodel.cwl/concatenate_matches/result"
                    ],
                    "id": "#cmsearch-multimodel.cwl/concatenate_matches"
                },
                {
                    "run": "#cmsearch-deoverlap.cwl",
                    "in": [
                        {
                            "source": "#cmsearch-multimodel.cwl/clan_info",
                            "id": "#cmsearch-multimodel.cwl/remove_overlaps/clan_information"
                        },
                        {
                            "source": "#cmsearch-multimodel.cwl/concatenate_matches/result",
                            "id": "#cmsearch-multimodel.cwl/remove_overlaps/cmsearch_matches"
                        }
                    ],
                    "out": [
                        "#cmsearch-multimodel.cwl/remove_overlaps/deoverlapped_matches"
                    ],
                    "id": "#cmsearch-multimodel.cwl/remove_overlaps"
                }
            ],
            "id": "#cmsearch-multimodel.cwl"
        },
        {
            "class": "Workflow",
            "label": "EMG assembly for paired end Illumina",
            "requirements": [
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "SchemaDefRequirement",
                    "types": [
                        {
                            "$import": "#FragGeneScan-model.yaml/model"
                        },
                        {
                            "$import": "#InterProScan-apps.yaml/apps"
                        },
                        {
                            "$import": "#InterProScan-protein_formats.yaml/protein_formats"
                        },
                        {
                            "$import": "#esl-reformat-replace.yaml/replace"
                        },
                        {
                            "$import": "#biom-convert-table.yaml/table_type"
                        }
                    ]
                }
            ],
            "inputs": [
                {
                    "type": "int",
                    "doc": "in Gb",
                    "id": "#main/assembly_mem_limit"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_1930",
                    "id": "#main/forward_reads"
                },
                {
                    "type": "#FragGeneScan-model.yaml/model",
                    "id": "#main/fraggenescan_model"
                },
                {
                    "type": "File",
                    "id": "#main/go_summary_config"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "secondaryFiles": ".mscluster",
                    "id": "#main/mapseq_ref"
                },
                {
                    "type": "File",
                    "id": "#main/mapseq_taxonomy"
                },
                {
                    "type": "File",
                    "id": "#main/ncRNA_other_model_clans"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/ncRNA_other_models"
                },
                {
                    "type": "File",
                    "id": "#main/ncRNA_ribosomal_model_clans"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/ncRNA_ribosomal_models"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_1930",
                    "id": "#main/reverse_reads"
                },
                {
                    "type": "string",
                    "id": "#main/sequencing_run_id"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_1930",
                    "id": "#main/unpaired_reads"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/extract_SSUs/sequences",
                    "id": "#main/SSUs"
                },
                {
                    "type": "File",
                    "outputSource": "#main/functional_analysis/functional_annotations",
                    "id": "#main/annotations"
                },
                {
                    "type": "File",
                    "outputSource": "#main/classify_SSUs/classifications",
                    "id": "#main/classifications"
                },
                {
                    "type": "File",
                    "outputSource": "#main/find_other_ncRNAs/matches",
                    "id": "#main/other_ncRNAs"
                },
                {
                    "type": "File",
                    "outputSource": "#main/convert_otu_counts_to_hdf5/result",
                    "id": "#main/otu_counts_hdf5"
                },
                {
                    "type": "File",
                    "outputSource": "#main/convert_otu_counts_to_json/result",
                    "id": "#main/otu_counts_json"
                },
                {
                    "type": "File",
                    "outputSource": "#main/visualize_otu_counts/otu_visualization",
                    "id": "#main/otu_visualization"
                },
                {
                    "type": "File",
                    "outputSource": "#main/ORF_prediction/predictedCDS",
                    "id": "#main/pCDS"
                },
                {
                    "type": "File",
                    "outputSource": "#main/discard_short_scaffolds/filtered_sequences",
                    "id": "#main/scaffolds"
                }
            ],
            "steps": [
                {
                    "run": "#orf_prediction.cwl",
                    "in": [
                        {
                            "default": true,
                            "id": "#main/ORF_prediction/completeSeq"
                        },
                        {
                            "source": "#main/fraggenescan_model",
                            "id": "#main/ORF_prediction/model"
                        },
                        {
                            "source": "#main/discard_short_scaffolds/filtered_sequences",
                            "id": "#main/ORF_prediction/sequence"
                        }
                    ],
                    "out": [
                        "#main/ORF_prediction/predictedCDS"
                    ],
                    "id": "#main/ORF_prediction"
                },
                {
                    "run": "#metaspades.cwl",
                    "in": [
                        {
                            "source": "#main/forward_reads",
                            "id": "#main/assembly/forward_reads"
                        },
                        {
                            "source": "#main/assembly_mem_limit",
                            "id": "#main/assembly/memory_limit"
                        },
                        {
                            "source": "#main/reverse_reads",
                            "id": "#main/assembly/reverse_reads"
                        },
                        {
                            "source": "#main/unpaired_reads",
                            "id": "#main/assembly/unpaired_reads"
                        }
                    ],
                    "out": [
                        "#main/assembly/scaffolds"
                    ],
                    "id": "#main/assembly"
                },
                {
                    "run": "#mapseq.cwl",
                    "in": [
                        {
                            "source": "#main/mapseq_ref",
                            "id": "#main/classify_SSUs/database"
                        },
                        {
                            "source": "#main/extract_SSUs/sequences",
                            "id": "#main/classify_SSUs/sequences"
                        },
                        {
                            "source": "#main/mapseq_taxonomy",
                            "id": "#main/classify_SSUs/taxonomy"
                        }
                    ],
                    "out": [
                        "#main/classify_SSUs/classifications"
                    ],
                    "id": "#main/classify_SSUs"
                },
                {
                    "run": "#mapseq2biom.cwl",
                    "in": [
                        {
                            "source": "#main/sequencing_run_id",
                            "id": "#main/convert_classifications_to_otu_counts/label"
                        },
                        {
                            "source": "#main/mapseq_taxonomy",
                            "id": "#main/convert_classifications_to_otu_counts/otu_table"
                        },
                        {
                            "source": "#main/classify_SSUs/classifications",
                            "id": "#main/convert_classifications_to_otu_counts/query"
                        }
                    ],
                    "out": [
                        "#main/convert_classifications_to_otu_counts/otu_counts",
                        "#main/convert_classifications_to_otu_counts/krona_otu_counts"
                    ],
                    "id": "#main/convert_classifications_to_otu_counts"
                },
                {
                    "run": "#biom-convert.cwl",
                    "in": [
                        {
                            "source": "#main/convert_classifications_to_otu_counts/otu_counts",
                            "id": "#main/convert_otu_counts_to_hdf5/biom"
                        },
                        {
                            "default": true,
                            "id": "#main/convert_otu_counts_to_hdf5/hdf5"
                        },
                        {
                            "default": "OTU table",
                            "id": "#main/convert_otu_counts_to_hdf5/table_type"
                        }
                    ],
                    "out": [
                        "#main/convert_otu_counts_to_hdf5/result"
                    ],
                    "id": "#main/convert_otu_counts_to_hdf5"
                },
                {
                    "run": "#biom-convert.cwl",
                    "in": [
                        {
                            "source": "#main/convert_classifications_to_otu_counts/otu_counts",
                            "id": "#main/convert_otu_counts_to_json/biom"
                        },
                        {
                            "default": true,
                            "id": "#main/convert_otu_counts_to_json/json"
                        },
                        {
                            "default": "OTU table",
                            "id": "#main/convert_otu_counts_to_json/table_type"
                        }
                    ],
                    "out": [
                        "#main/convert_otu_counts_to_json/result"
                    ],
                    "id": "#main/convert_otu_counts_to_json"
                },
                {
                    "run": "#discard_short_seqs.cwl",
                    "in": [
                        {
                            "default": 100,
                            "id": "#main/discard_short_scaffolds/minimum_length"
                        },
                        {
                            "source": "#main/assembly/scaffolds",
                            "id": "#main/discard_short_scaffolds/sequences"
                        }
                    ],
                    "out": [
                        "#main/discard_short_scaffolds/filtered_sequences"
                    ],
                    "id": "#main/discard_short_scaffolds"
                },
                {
                    "run": "#esl-sfetch-manyseqs.cwl",
                    "in": [
                        {
                            "source": "#main/index_scaffolds/sequences_with_index",
                            "id": "#main/extract_SSUs/indexed_sequences"
                        },
                        {
                            "source": "#main/get_SSU_coords/SSU_coordinates",
                            "id": "#main/extract_SSUs/names"
                        },
                        {
                            "default": true,
                            "id": "#main/extract_SSUs/names_contain_subseq_coords"
                        }
                    ],
                    "out": [
                        "#main/extract_SSUs/sequences"
                    ],
                    "id": "#main/extract_SSUs"
                },
                {
                    "run": "#cmsearch-multimodel.cwl",
                    "in": [
                        {
                            "source": "#main/ncRNA_other_model_clans",
                            "id": "#main/find_other_ncRNAs/clan_info"
                        },
                        {
                            "source": "#main/ncRNA_other_models",
                            "id": "#main/find_other_ncRNAs/covariance_models"
                        },
                        {
                            "source": "#main/discard_short_scaffolds/filtered_sequences",
                            "id": "#main/find_other_ncRNAs/query_sequences"
                        }
                    ],
                    "out": [
                        "#main/find_other_ncRNAs/matches"
                    ],
                    "id": "#main/find_other_ncRNAs"
                },
                {
                    "run": "#cmsearch-multimodel.cwl",
                    "in": [
                        {
                            "source": "#main/ncRNA_ribosomal_model_clans",
                            "id": "#main/find_ribosomal_ncRNAs/clan_info"
                        },
                        {
                            "source": "#main/ncRNA_ribosomal_models",
                            "id": "#main/find_ribosomal_ncRNAs/covariance_models"
                        },
                        {
                            "source": "#main/discard_short_scaffolds/filtered_sequences",
                            "id": "#main/find_ribosomal_ncRNAs/query_sequences"
                        }
                    ],
                    "out": [
                        "#main/find_ribosomal_ncRNAs/matches"
                    ],
                    "id": "#main/find_ribosomal_ncRNAs"
                },
                {
                    "doc": "Matches are generated against predicted CDS, using a sub set of databases\n(Pfam, TIGRFAM, PRINTS, PROSITE patterns, Gene3d) from InterPro.\n",
                    "run": "#functional_analysis.cwl",
                    "in": [
                        {
                            "source": "#main/go_summary_config",
                            "id": "#main/functional_analysis/go_summary_config"
                        },
                        {
                            "source": "#main/ORF_prediction/predictedCDS",
                            "id": "#main/functional_analysis/predicted_CDS"
                        }
                    ],
                    "out": [
                        "#main/functional_analysis/functional_annotations",
                        "#main/functional_analysis/go_summary",
                        "#main/functional_analysis/go_summary_slim"
                    ],
                    "id": "#main/functional_analysis"
                },
                {
                    "run": "#SSU-from-tablehits.cwl",
                    "in": [
                        {
                            "source": "#main/find_ribosomal_ncRNAs/matches",
                            "id": "#main/get_SSU_coords/table_hits"
                        }
                    ],
                    "out": [
                        "#main/get_SSU_coords/SSU_coordinates"
                    ],
                    "id": "#main/get_SSU_coords"
                },
                {
                    "run": "#esl-sfetch-index.cwl",
                    "in": [
                        {
                            "source": "#main/discard_short_scaffolds/filtered_sequences",
                            "id": "#main/index_scaffolds/sequences"
                        }
                    ],
                    "out": [
                        "#main/index_scaffolds/sequences_with_index"
                    ],
                    "id": "#main/index_scaffolds"
                },
                {
                    "run": "#krona.cwl",
                    "in": [
                        {
                            "source": "#main/convert_classifications_to_otu_counts/krona_otu_counts",
                            "id": "#main/visualize_otu_counts/otu_counts"
                        }
                    ],
                    "out": [
                        "#main/visualize_otu_counts/otu_visualization"
                    ],
                    "id": "#main/visualize_otu_counts"
                }
            ],
            "id": "#main",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "Workflow",
            "label": "functional analysis prediction with InterProScan",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "SchemaDefRequirement",
                    "types": [
                        {
                            "$import": "#esl-reformat-replace.yaml/replace"
                        },
                        {
                            "$import": "#InterProScan-apps.yaml/apps"
                        },
                        {
                            "$import": "#InterProScan-protein_formats.yaml/protein_formats"
                        }
                    ]
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#functional_analysis.cwl/go_summary_config"
                },
                {
                    "type": "File",
                    "id": "#functional_analysis.cwl/predicted_CDS"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#functional_analysis.cwl/combine_annotations/result",
                    "id": "#functional_analysis.cwl/functional_annotations"
                },
                {
                    "type": "File",
                    "outputSource": "#functional_analysis.cwl/summarize_with_GO/go_summary",
                    "id": "#functional_analysis.cwl/go_summary"
                },
                {
                    "type": "File",
                    "outputSource": "#functional_analysis.cwl/summarize_with_GO/go_summary_slim",
                    "id": "#functional_analysis.cwl/go_summary_slim"
                }
            ],
            "steps": [
                {
                    "run": "#fasta_chunker.cwl",
                    "in": [
                        {
                            "default": 10000,
                            "id": "#functional_analysis.cwl/chunk_inputs/chunk_size"
                        },
                        {
                            "source": "#functional_analysis.cwl/remove_asterisks_and_reformat/reformatted_sequences",
                            "id": "#functional_analysis.cwl/chunk_inputs/seqs"
                        }
                    ],
                    "out": [
                        "#functional_analysis.cwl/chunk_inputs/chunks"
                    ],
                    "id": "#functional_analysis.cwl/chunk_inputs"
                },
                {
                    "run": "#concatenate.cwl",
                    "in": [
                        {
                            "source": "#functional_analysis.cwl/functional_analysis/i5Annotations",
                            "id": "#functional_analysis.cwl/combine_annotations/files"
                        }
                    ],
                    "out": [
                        "#functional_analysis.cwl/combine_annotations/result"
                    ],
                    "id": "#functional_analysis.cwl/combine_annotations"
                },
                {
                    "doc": "Matches are generated against predicted CDS, using a sub set of databases\n(Pfam, TIGRFAM, PRINTS, PROSITE patterns, Gene3d) from InterPro. \n",
                    "run": "#InterProScan5.21-60.cwl",
                    "in": [
                        {
                            "default": [
                                "Pfam",
                                "TIGRFAM",
                                "PRINTS",
                                "ProSitePatterns",
                                "Gene3D"
                            ],
                            "id": "#functional_analysis.cwl/functional_analysis/applications"
                        },
                        {
                            "source": "#functional_analysis.cwl/chunk_inputs/chunks",
                            "id": "#functional_analysis.cwl/functional_analysis/proteinFile"
                        }
                    ],
                    "scatter": "#functional_analysis.cwl/functional_analysis/proteinFile",
                    "out": [
                        "#functional_analysis.cwl/functional_analysis/i5Annotations"
                    ],
                    "id": "#functional_analysis.cwl/functional_analysis"
                },
                {
                    "run": "#esl-reformat.cwl",
                    "in": [
                        {
                            "default": {
                                "find": "*",
                                "replace": "X"
                            },
                            "id": "#functional_analysis.cwl/remove_asterisks_and_reformat/replace"
                        },
                        {
                            "source": "#functional_analysis.cwl/predicted_CDS",
                            "id": "#functional_analysis.cwl/remove_asterisks_and_reformat/sequences"
                        }
                    ],
                    "out": [
                        "#functional_analysis.cwl/remove_asterisks_and_reformat/reformatted_sequences"
                    ],
                    "id": "#functional_analysis.cwl/remove_asterisks_and_reformat"
                },
                {
                    "doc": "A summary of Gene Ontology (GO) terms derived from InterPro matches to\nthe sample. It is generated using a reduced list of GO terms called\nGO slim (http://www.geneontology.org/ontology/subsets/goslim_metagenomics.obo)\n",
                    "run": "#go_summary.cwl",
                    "in": [
                        {
                            "source": "#functional_analysis.cwl/combine_annotations/result",
                            "id": "#functional_analysis.cwl/summarize_with_GO/InterProScan_results"
                        },
                        {
                            "source": "#functional_analysis.cwl/go_summary_config",
                            "id": "#functional_analysis.cwl/summarize_with_GO/config"
                        }
                    ],
                    "out": [
                        "#functional_analysis.cwl/summarize_with_GO/go_summary",
                        "#functional_analysis.cwl/summarize_with_GO/go_summary_slim"
                    ],
                    "id": "#functional_analysis.cwl/summarize_with_GO"
                }
            ],
            "id": "#functional_analysis.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "Workflow",
            "label": "Find reads with predicted coding sequences above 60 AA in length",
            "requirements": [
                {
                    "class": "SchemaDefRequirement",
                    "types": [
                        {
                            "$import": "#FragGeneScan-model.yaml/model"
                        }
                    ]
                }
            ],
            "inputs": [
                {
                    "type": "boolean",
                    "id": "#orf_prediction.cwl/completeSeq"
                },
                {
                    "type": "#FragGeneScan-model.yaml/model",
                    "id": "#orf_prediction.cwl/model"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "id": "#orf_prediction.cwl/sequence"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "outputSource": "#orf_prediction.cwl/remove_short_pCDS/filtered_sequences",
                    "id": "#orf_prediction.cwl/predictedCDS"
                }
            ],
            "steps": [
                {
                    "doc": "Find reads with predicted coding sequences (pCDS)\n",
                    "run": "#FragGeneScan1_20.cwl",
                    "in": [
                        {
                            "source": "#orf_prediction.cwl/completeSeq",
                            "id": "#orf_prediction.cwl/ORF_prediction/completeSeq"
                        },
                        {
                            "source": "#orf_prediction.cwl/model",
                            "id": "#orf_prediction.cwl/ORF_prediction/model"
                        },
                        {
                            "source": "#orf_prediction.cwl/sequence",
                            "id": "#orf_prediction.cwl/ORF_prediction/sequence"
                        }
                    ],
                    "out": [
                        "#orf_prediction.cwl/ORF_prediction/predictedCDS"
                    ],
                    "id": "#orf_prediction.cwl/ORF_prediction"
                },
                {
                    "run": "#discard_short_seqs.cwl",
                    "in": [
                        {
                            "default": 60,
                            "id": "#orf_prediction.cwl/remove_short_pCDS/minimum_length"
                        },
                        {
                            "source": "#orf_prediction.cwl/ORF_prediction/predictedCDS",
                            "id": "#orf_prediction.cwl/remove_short_pCDS/sequences"
                        }
                    ],
                    "out": [
                        "#orf_prediction.cwl/remove_short_pCDS/filtered_sequences"
                    ],
                    "id": "#orf_prediction.cwl/remove_short_pCDS"
                }
            ],
            "id": "#orf_prediction.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        }
    ],
    "cwlVersion": "v1.0",
    "$schemas": [
        "https://schema.org/docs/schema_org_rdfa.html",
        "http://edamontology.org/EDAM_1.16.owl"
    ],
    "$namespaces": {
        "edam": "http://edamontology.org/",
        "s": "http://schema.org/"
    }
}
